pro ssw_limbcalc, index, data, regions, region_info, minpix=minpix, $
		  phisort=phisort
;
;   Name: ssw_limbcalc
;
;   Purpose: calculate the ssw_limbstuff parameters  (tag values)
;
;   Input Parameters:
;      index, data - the usual 
;      regions     - 'blobs' over the limb (blob coloring) (from ssw_limbstuff)
;
;   Output Parameters 
;      region_info - structure - info on each region w/npix > minpix 
;  
;   Keyword Parameters:
;
;   Calling Examples:
;      ssw_limbcalc, index, data, regions, region_info [,minpix=xx]
;                     (in)  (in)   (in)    (out)
;   History:
;      16-jun-1997 - S.L.Freeland (break code from ssw_limbstuff.pro)
;      18-jun-1997 - S.L.Freeland - add PHISORT keyword and function
;      16-Jul-2001 - S.L.Freeland - add MOMENT and STD_DEV information
;
;-
debug=keyword_set(debug)
if not keyword_set(minpix) then minpix=20

; ------------------------ check input -------------------------------
if  n_params() lt 2 then  begin
    prstr,strjustify(['IDL> ssw_limbcalc,regions, rinfo [,rnum]'],/box),/nomore
    return
endif    
; -------------------------------------------------------------------------

; ------- define the info structure  --------
if not data_chk(info_temp,/struct) then    $ ;
   info_temp={rnum:0l,                     $ ; region# (=pix value in REGIONS)
              npix:0l,                     $ ; number of pixels in region
              centroid:fltarr(2),          $ ; region weighted centroid
              rtot:0.0,                    $ ; region total
              rmax:0.0,                    $ ; region maximum
              ravg:0.0,                    $ ; region average
              mean:0.0,                    $ ; See RSI MOMENT FUNCTION
              variance:0.0,                $ ;  ""
              skewness:0.0,                $ ;  ""
              kurtosis:0.0,                $ ;  ""
              mdev:0.0,                    $ ; Mean absolute deviation
              sdev:0.0,                    $ ; Standard deviation
              rss:0.0,                     $ ; cent dist from sun center       
              phi:0.0,                     $ ; angle (degrees)
              extentrss:fltarr(2),         $ ; radial extent of region SS [low, high] pix
              extentphi:fltarr(2),         $ ; extent angle [low,high] deg.
              extentx:intarr(2),           $ ;
              extenty:intarr(2)            $ ;
                                           } ; 
; -------------------------------------------

; --------- Tag regions and filter out the too-small ---------------------
rhist=(histogram(regions))(1:*)          ; ignore element (0) => no region
nregions=n_elements(rhist)               ; total blobs identified
which=where(rhist ge minpix, rcnt)       ; filter "too small" regions
; ----------------------------------------------------------------------

region_info=replicate(info_temp,rcnt)       ; one per "accepted" region
if rcnt eq 1 then which=which(0)
region_info.rnum=which+1                    ; fill in region# (adjust for 0)
region_info.npix=rhist(which)               ; fill in #pix/region

sdata=size(regions)
empty=make_array(size=sdata)                ; make a useful template image 
sreg=strtrim(which+1,2)

;---- per-region loop for additionl info ---;
for i=0,rcnt-1 do begin                     ; for each region, gather some info
   message,/info,"Region>>> " + sreg(i)     ; region status message
   tempty=empty                             ; use template
   ss=where(regions eq region_info(i).rnum) ; pixel SS for region(i)
   tempty(ss)=data(ss)                      ; get corresponding data
   region_info(i).rtot=total(data(ss))      ; total->str
   region_info(i).ravg=average(data(ss))    ; average->str
   region_info(i).rmax=max(data(ss))        ; max->str
   centroidw,tempty,xw,yw                   ; calculate centroid
   region_info(i).centroid=[xw,yw]          ; centroid->str
;  --------- existing  conv_XXX function?? -----------------------------
   extentx=ss mod sdata(1)                  ; region -> xcoord (pix)
   extenty=ss/(sdata(2))                    ; region -> ycoord (pix)
   region_info(i).extentx=[min(extentx),max(extentx)]
   region_info(i).extenty=[min(extenty),max(extenty)]
   conv_pix2polar,index,extentx,extenty,extentr,extentphi
   region_info(i).extentrss=[min(extentr),max(extentr)]  ; polar extent
   region_info(i).extentphi=[min(extentphi),max(extentphi)]  ; polar extent
   momreg=moment(data(ss),sdev=sdev,mdev=mdev)
   region_info(i).mean=momreg(0)
   region_info(i).variance=momreg(1)
   region_info(i).skewness=momreg(2)
   region_info(i).kurtosis=momreg(3)
   region_info(i).mdev=mdev
   region_info(i).sdev=sdev
   if debug then stop,'in for loop'
endfor                                     ;
;-------------------------------------------;

; post processing conversions
; -------------- centroid [x,y] -> polar ---------------------
conv_pix2polar,index,region_info.centroid(0),region_info.centroid(1),cr,cphi
region_info.rss=cr
region_info.phi=cphi

if debug then stop

if keyword_set(phisort) then begin
   message,/info,"Sorting by region Low PHI
   region_info=region_info(sort(region_info.extentphi(0)))
endif   

return
end
